@@ -2,7 +2,7 @@
  *      main-win.c
  *
  *      Copyright 2009 - 2012 Hong Jen Yee (PCMan) <pcman.tw@gmail.com>
- *      Copyright 2012-2014 Andriy Grytsenko (LStranger) <andrej@rep.kiev.ua>
+ *      Copyright 2012-2015 Andriy Grytsenko (LStranger) <andrej@rep.kiev.ua>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -319,12 +319,13 @@ static void update_file_menu(FmMainWin* win, FmPath *path)
 {
     GtkAction *act;
     /* FmFolderView *fv = win->folder_view; */
+    gboolean can_term = pcmanfm_can_open_path_in_terminal(path);
 
     act = gtk_ui_manager_get_action(win->ui, "/menubar/ToolMenu/Term");
-    gtk_action_set_sensitive(act, path && fm_path_is_native(path));
+    gtk_action_set_sensitive(act, path && can_term);
 #if FM_CHECK_VERSION(1, 2, 0)
     act = gtk_ui_manager_get_action(win->ui, "/menubar/ToolMenu/Launch");
-    gtk_action_set_sensitive(act, path && fm_path_is_native(path));
+    gtk_action_set_sensitive(act, path && can_term);
 #endif
     act = gtk_ui_manager_get_action(win->ui, "/menubar/GoMenu/Up");
     gtk_action_set_sensitive(act, path && fm_path_get_parent(path));
@@ -372,8 +373,10 @@ static void on_folder_view_sel_changed(FmFolderView* fv, gint n_sel, FmMainWin*
     {
         FmFileInfoList *files = fm_folder_view_dup_selected_files(fv);
         FmFileInfo *fi = fm_file_info_list_peek_head(files);
-        if (fm_file_info_can_set_name(fi) && !fm_file_info_is_shortcut(fi)
-            && !fm_file_info_is_desktop_entry(fi))
+#if FM_CHECK_VERSION(1, 2, 0)
+        if (fm_file_info_can_set_name(fi))
+#endif
+          if (!fm_file_info_is_shortcut(fi) && !fm_file_info_is_desktop_entry(fi))
             has_selected = TRUE;
         fm_file_info_list_unref(files);
     }
@@ -1140,10 +1143,14 @@ static void on_about(GtkAction* act, FmMainWin* win)
 {
     if(!about_dlg)
     {
-        GtkBuilder* builder = gtk_builder_new();
         GString *comments = g_string_new(_("Lightweight file manager\n"));
+#if GTK_CHECK_VERSION(3, 10, 0)
+        GtkBuilder* builder = gtk_builder_new_from_file(PACKAGE_UI_DIR "/about.ui");
+#else
+        GtkBuilder* builder = gtk_builder_new();
 
         gtk_builder_add_from_file(builder, PACKAGE_UI_DIR "/about.ui", NULL);
+#endif
         about_dlg = GTK_ABOUT_DIALOG(gtk_builder_get_object(builder, "dlg"));
 #if FM_CHECK_VERSION(1, 2, 0)
         g_string_append_printf(comments, _("using LibFM ver. %s\n"), fm_version());
@@ -1634,6 +1641,7 @@ static void update_statusbar(FmMainWin* win)
     if(text)
         gtk_statusbar_push(win->statusbar, win->statusbar_ctx, text);
 
+    gtk_statusbar_pop(win->statusbar, win->statusbar_ctx2);
     text = fm_tab_page_get_status_text(page, FM_STATUS_TEXT_SELECTED_FILES);
     if(text)
         gtk_statusbar_push(win->statusbar, win->statusbar_ctx2, text);
@@ -2106,7 +2114,12 @@ static void on_tab_page_status_text(FmTabPage* page, guint type, const char* sta
         gtk_statusbar_pop(win->statusbar, win->statusbar_ctx);
         if(status_text)
             gtk_statusbar_push(win->statusbar, win->statusbar_ctx, status_text);
-        break;
+        else
+            break; /* no updates are required */
+        if (fm_folder_view_get_n_selected_files(win->folder_view) == 0)
+            break;
+        /* otherwise put selection info on statusbar, continue with update */
+        status_text = fm_tab_page_get_status_text(page, FM_STATUS_TEXT_SELECTED_FILES);
     case FM_STATUS_TEXT_SELECTED_FILES:
         gtk_statusbar_pop(win->statusbar, win->statusbar_ctx2);
         if(status_text)
